=== modified file 'plugin/logging_stats/cumulative_stats.cc'
--- plugin/logging_stats/cumulative_stats.cc	2010-06-25 03:22:55 +0000
+++ plugin/logging_stats/cumulative_stats.cc	2010-08-18 02:17:48 +0000
@@ -31,6 +31,7 @@
 #include "cumulative_stats.h"
 
 using namespace std;
+using namespace drizzled;
 
 CumulativeStats::CumulativeStats(uint32_t in_cumulative_stats_by_user_max) 
     :
@@ -50,6 +51,12 @@
   isOpenUserSlots= true;
   global_stats= new GlobalStats();
   global_status_vars= new StatusVars();
+
+  /* calculate the approximate memory allocation for the cumulative statistics */
+  size_t statusVarsSize= sizeof(StatusVars) + sizeof(system_status_var);
+  size_t userCommandsSize= sizeof(UserCommands) + sizeof(uint64_t) * SQLCOM_END;
+
+  cumulative_size_bytes= (statusVarsSize + userCommandsSize) * cumulative_stats_by_user_max; 
 }
 
 CumulativeStats::~CumulativeStats()

=== modified file 'plugin/logging_stats/cumulative_stats.h'
--- plugin/logging_stats/cumulative_stats.h	2010-06-25 03:22:55 +0000
+++ plugin/logging_stats/cumulative_stats.h	2010-08-18 02:17:48 +0000
@@ -73,6 +73,11 @@
     return cumulative_stats_by_user_max; 
   }
 
+  uint64_t getCumulativeSizeBytes()
+  {
+    return cumulative_size_bytes;
+  }
+
   int32_t getCumulativeStatsLastValidIndex();
 
   bool hasOpenUserSlots()
@@ -88,6 +93,7 @@
   std::vector<ScoreboardSlot* > *cumulative_stats_by_user_vector;
   GlobalStats *global_stats; 
   StatusVars *global_status_vars;
+  uint64_t cumulative_size_bytes;
   int32_t cumulative_stats_by_user_max;
   drizzled::atomic<int32_t> last_valid_index;
   bool isOpenUserSlots;

=== modified file 'plugin/logging_stats/logging_stats.cc'
--- plugin/logging_stats/logging_stats.cc	2010-08-03 12:30:13 +0000
+++ plugin/logging_stats/logging_stats.cc	2010-08-18 02:17:48 +0000
@@ -219,6 +219,8 @@
 
 static CumulativeUserStatsTool *cumulative_user_stats_tool= NULL;
 
+static ScoreboardStatsTool *scoreboard_stats_tool= NULL;
+
 static void enable(Session *,
                    drizzle_sys_var *,
                    void *var_ptr,
@@ -290,6 +292,13 @@
     return true;
   }
 
+  scoreboard_stats_tool= new(nothrow)ScoreboardStatsTool(logging_stats);
+  
+  if (! scoreboard_stats_tool)
+  {
+    return true;
+  }
+
   return false;
 }
 
@@ -339,6 +348,7 @@
   context.add(session_status_tool);
   context.add(global_status_tool);
   context.add(cumulative_user_stats_tool);
+  context.add(scoreboard_stats_tool);
 
   if (sysvar_logging_stats_enabled)
   {

=== modified file 'plugin/logging_stats/scoreboard.cc'
--- plugin/logging_stats/scoreboard.cc	2010-08-06 23:09:40 +0000
+++ plugin/logging_stats/scoreboard.cc	2010-08-18 02:17:48 +0000
@@ -60,7 +60,7 @@
 {
 
   /* calculate the number of elements in each bucket */
-  uint32_t number_per_bucket= static_cast<uint32_t> ( ceil( static_cast<double>(number_sessions) / static_cast<double>(number_buckets) ) );
+  number_per_bucket= static_cast<uint32_t> ( ceil( static_cast<double>(number_sessions) / static_cast<double>(number_buckets) ) );
 
   /* populate the vector of scoreboard vectors */
   for (uint32_t j= 0; j < number_buckets; ++j)
@@ -95,6 +95,12 @@
       vector_of_scoreboard_locks.insert(vector_of_scoreboard_locks_iterator, lock);   
   } 
   vector_of_scoreboard_locks.resize(number_buckets);
+
+  /* calculate the approximate memory allocation of the scoreboard */
+  size_t statusVarsSize= sizeof(StatusVars) + sizeof(system_status_var);
+  size_t userCommandsSize= sizeof(UserCommands) + sizeof(uint64_t) * SQLCOM_END;
+
+  scoreboard_size_bytes= (statusVarsSize + userCommandsSize) * number_per_bucket * number_buckets;
 }
 
 Scoreboard::~Scoreboard()

=== modified file 'plugin/logging_stats/scoreboard.h'
--- plugin/logging_stats/scoreboard.h	2010-08-16 23:22:48 +0000
+++ plugin/logging_stats/scoreboard.h	2010-08-18 02:17:48 +0000
@@ -71,6 +71,11 @@
     return number_buckets;
   }
 
+  uint32_t getNumberPerBucket()
+  {
+    return number_per_bucket;
+  }
+
   uint64_t getScoreboardSizeBytes()
   {
     return scoreboard_size_bytes;
@@ -88,6 +93,7 @@
 
 private:
   uint32_t number_sessions;
+  uint32_t number_per_bucket;
   uint32_t number_buckets;
   uint64_t scoreboard_size_bytes;
   std::vector<std::vector<ScoreboardSlot* >* > vector_of_scoreboard_vectors;

=== modified file 'plugin/logging_stats/stats_schema.cc'
--- plugin/logging_stats/stats_schema.cc	2010-08-04 03:16:34 +0000
+++ plugin/logging_stats/stats_schema.cc	2010-08-18 02:17:48 +0000
@@ -454,3 +454,41 @@
 
   return false;
 }
+
+ScoreboardStatsTool::ScoreboardStatsTool(LoggingStats *logging_stats) :
+  plugin::TableFunction("DATA_DICTIONARY", "SCOREBOARD_STATISTICS")
+{
+  outer_logging_stats= logging_stats;
+
+  add_field("SCOREBOARD_SIZE", TableFunction::NUMBER);
+  add_field("NUMBER_OF_RANGE_LOCKS", TableFunction::NUMBER);
+  add_field("MAX_USERS_LOGGED", TableFunction::NUMBER);
+  add_field("MEMORY_USAGE_BYTES", TableFunction::NUMBER);
+}
+
+ScoreboardStatsTool::Generator::Generator(Field **arg, LoggingStats *logging_stats) :
+  plugin::TableFunction::Generator(arg)
+{
+  inner_logging_stats= logging_stats;
+  is_last_record= false; 
+}
+
+bool ScoreboardStatsTool::Generator::populate()
+{
+  if (is_last_record)
+  {
+    return false;
+  }
+
+  Scoreboard *scoreboard= inner_logging_stats->getCurrentScoreboard();
+  CumulativeStats *cumulativeStats= inner_logging_stats->getCumulativeStats();
+
+  push(static_cast<uint64_t>(scoreboard->getNumberPerBucket() * scoreboard->getNumberBuckets()));
+  push(static_cast<uint64_t>(scoreboard->getNumberBuckets()));
+  push(static_cast<uint64_t>(cumulativeStats->getCumulativeStatsByUserMax()));
+  push(cumulativeStats->getCumulativeSizeBytes() + scoreboard->getScoreboardSizeBytes()); 
+  
+  is_last_record= true;
+
+  return true;
+}

=== modified file 'plugin/logging_stats/stats_schema.h'
--- plugin/logging_stats/stats_schema.h	2010-08-04 03:16:34 +0000
+++ plugin/logging_stats/stats_schema.h	2010-08-18 02:17:48 +0000
@@ -179,4 +179,29 @@
   LoggingStats *outer_logging_stats;
 };
 
+class ScoreboardStatsTool : public drizzled::plugin::TableFunction
+{
+public:
+
+  ScoreboardStatsTool(LoggingStats *logging_stats);
+
+  class Generator : public drizzled::plugin::TableFunction::Generator
+  {
+  public:
+    Generator(drizzled::Field **arg, LoggingStats *logging_stats);
+
+    bool populate();
+  private:
+    LoggingStats *inner_logging_stats;
+    bool is_last_record;
+  };
+
+  Generator *generator(drizzled::Field **arg)
+  {
+    return new Generator(arg, outer_logging_stats);
+  }
+private:
+  LoggingStats *outer_logging_stats;
+};
+
 #endif /* PLUGIN_LOGGING_STATS_STATS_SCHEMA_H */

